==> adapter-layer-0.17.0.tgz: package/adapter-layer.js <==
"use strict";
(() => {
  // src/index.ts
  var TYPE_MAP = {
    choice: "LIST",
    color: "COLOR",
    range: "NUMBER",
    toggle: "BOOLEAN",
    text: "HASH"
  };
  var { isString } = $genart.utils;
  var LayerAdapter = class {
    mode = "play";
    params;
    cache = {};
    // protected layerParams!: Record<string, Parameter> | undefined;
    constructor() {
      $layer.debug = true;
      $genart.on(
        "genart:state-change",
        ({ state }) => state === "ready" && !$layer.controlled && $genart.start()
      );
      window.addEventListener("layer:play", () => {
        if ($genart.state === "ready" || $genart.state === "stop") {
          $genart.start($genart.state === "stop");
        }
      });
      window.addEventListener("layer:pause", () => $genart.stop());
      window.addEventListener("layer:paramchange", (e) => {
        const { id, value } = e.detail;
        if (this.params?.[id]?.update !== "reload") {
          $genart.setParamValue(id, value);
        }
      });
      window.addEventListener("layer:dimensionschange", (e) => {
        $genart.emit({
          type: "genart:resize",
          screen: { ...e.detail, dpr: 1 }
        });
      });
    }
    get id() {
      return "@genart-api/adapter-layer";
    }
    get screen() {
      return {
        width: $layer.width,
        height: $layer.height,
        dpr: 1
      };
    }
    get prng() {
      return {
        seed: $layer.uuid,
        rnd: $layer.prng,
        reset: () => $layer.prng
      };
    }
    async updateParam(id, param) {
      let value = $layer.parameters[id];
      if (param.type === "color") {
        if (!isString(value)) value = value.hex;
      }
      if (value == null || this.cache[id] === value) return;
      this.cache[id] = value;
      return { value };
    }
    async initParams(params) {
      this.params = params;
      const layerParams = [];
      for (let id in params) {
        const src = params[id];
        const kind = TYPE_MAP[src.type];
        if (!kind) {
          console.warn("layeradapter: unsupported ptype:", src.type);
          continue;
        }
        const dest = {
          id,
          kind,
          name: src.name || id,
          description: src.desc,
          default: src.default,
          customization_level: src.edit === "private" ? "ARTIST" : src.edit === "public" ? "VIEWER" : "CURATOR"
        };
        this.cache[id] = src.default;
        switch (src.type) {
          case "choice": {
            const $src = src;
            const $dest = dest;
            $dest.options = $src.options.map(
              (x) => Array.isArray(x) ? { value: x[0], label: x[1] } : { value: x, label: x }
            );
            break;
          }
          case "range": {
            const $src = src;
            const $dest = dest;
            $dest.min = $src.min;
            $dest.max = $src.max;
            $dest.step = $src.step;
            break;
          }
        }
        layerParams.push(dest);
      }
      await $layer.params(...layerParams);
    }
    setTraits() {
    }
    capture(canvas) {
      $layer.registerCanvas(canvas);
    }
  };
  $genart.setAdapter(new LayerAdapter());
})();

==> adapter-layer-0.17.1.tgz: package/adapter-layer.js <==
"use strict";
(() => {
  // src/index.ts
  var TYPE_MAP = {
    choice: "LIST",
    color: "COLOR",
    range: "NUMBER",
    toggle: "BOOLEAN",
    text: "HASH"
  };
  var { isString } = $genart.utils;
  var LayerAdapter = class {
    mode = "play";
    params;
    cache = {};
    // protected layerParams!: Record<string, Parameter> | undefined;
    constructor() {
      $layer.debug = true;
      $genart.on(
        "genart:state-change",
        ({ state }) => state === "ready" && !$layer.controlled && $genart.start()
      );
      window.addEventListener("layer:play", () => {
        if ($genart.state === "ready" || $genart.state === "stop") {
          $genart.start($genart.state === "stop");
        }
      });
      window.addEventListener("layer:pause", () => $genart.stop());
      window.addEventListener("layer:paramchange", (e) => {
        let { id, value } = e.detail;
        const param = this.params?.[id];
        if (param && param.update !== "reload") {
          if (param.type === "color") value = value.hex;
          $genart.setParamValue(id, value);
        }
      });
      window.addEventListener("layer:dimensionschange", (e) => {
        $genart.emit({
          type: "genart:resize",
          screen: { ...e.detail, dpr: 1 }
        });
      });
    }
    get id() {
      return "@genart-api/adapter-layer";
    }
    get screen() {
      return {
        width: $layer.width,
        height: $layer.height,
        dpr: 1
      };
    }
    get prng() {
      return {
        seed: $layer.uuid,
        rnd: $layer.prng,
        reset: () => $layer.prng
      };
    }
    async updateParam(id, param) {
      let value = $layer.parameters[id];
      if (param.type === "color") {
        if (!isString(value)) value = value.hex;
      }
      if (value == null || this.cache[id] === value) return;
      this.cache[id] = value;
      return { value };
    }
    async initParams(params) {
      this.params = params;
      const layerParams = [];
      for (let id in params) {
        const src = params[id];
        const kind = TYPE_MAP[src.type];
        if (!kind) {
          console.warn("layeradapter: unsupported ptype:", src.type);
          continue;
        }
        const dest = {
          id,
          kind,
          name: src.name || id,
          description: src.desc,
          default: src.default,
          customization_level: src.edit === "private" ? "ARTIST" : src.edit === "public" ? "VIEWER" : "CURATOR"
        };
        this.cache[id] = src.default;
        switch (src.type) {
          case "choice": {
            const $src = src;
            const $dest = dest;
            $dest.options = $src.options.map(
              (x) => Array.isArray(x) ? { value: x[0], label: x[1] } : { value: x, label: x }
            );
            break;
          }
          case "range": {
            const $src = src;
            const $dest = dest;
            $dest.min = $src.min;
            $dest.max = $src.max;
            $dest.step = $src.step;
            break;
          }
        }
        layerParams.push(dest);
      }
      await $layer.params(...layerParams);
    }
    setTraits() {
    }
    capture(canvas) {
      $layer.registerCanvas(canvas);
    }
  };
  $genart.setAdapter(new LayerAdapter());
})();
